package jalview.fts.threedbeacons;

import static org.testng.Assert.assertNull;
import static org.testng.AssertJUnit.assertEquals;
import static org.testng.AssertJUnit.assertTrue;

import java.net.URL;
import java.nio.charset.StandardCharsets;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

import org.testng.Assert;
import org.testng.annotations.AfterMethod;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

import jalview.fts.api.FTSDataColumnI;
import jalview.fts.api.FTSDataColumnI.FTSDataColumnGroupI;
import jalview.fts.core.FTSRestClient;
import jalview.fts.core.FTSRestRequest;
import jalview.fts.core.FTSRestResponse;
import jalview.fts.service.threedbeacons.TDBeaconsFTSRestClient;
import jalview.gui.JvOptionPane;

public class TDBeaconsFTSRestClientTest
{
  @BeforeClass(alwaysRun = true)
  public void setUpJvOptionPane()
  {
    JvOptionPane.setInteractiveMode(false);
    JvOptionPane.setMockResponse(JvOptionPane.CANCEL_OPTION);
  }

  private FTSRestClient ftsRestClient;

  @BeforeMethod(alwaysRun = true)
  public void setUp() throws Exception
  {
    ftsRestClient = new FTSRestClient()
    {

      @Override
      public String getColumnDataConfigFileName()
      {
        return "/fts/tdbeacons_data_columns.txt";
      }

      @Override
      public FTSRestResponse executeRequest(FTSRestRequest ftsRequest)
              throws Exception
      {
        return null;
      }
    };
  }

  @AfterMethod(alwaysRun = true)
  public void tearDown() throws Exception
  {
  }

  @Test
  public void getAllDefaulDisplayedDataColumns()
  {
    // to change when resources.tdbeacons_data_columns.txt is changed
    Assert.assertNotNull(
            ftsRestClient.getAllDefaultDisplayedFTSDataColumns());
    System.out
            .println(ftsRestClient.getAllDefaultDisplayedFTSDataColumns());
    Assert.assertTrue(!ftsRestClient.getAllDefaultDisplayedFTSDataColumns()
            .isEmpty());
    Assert.assertEquals(
            ftsRestClient.getAllDefaultDisplayedFTSDataColumns().size(),
            13);
  }

  @Test(groups = { "Functional" })
  public void getPrimaryKeyColumIndexTest()
  {
    Collection<FTSDataColumnI> wantedFields = ftsRestClient
            .getAllDefaultDisplayedFTSDataColumns();
    int foundIndex = -1;
    try
    {
      Assert.assertEquals(foundIndex, -1);
      foundIndex = ftsRestClient.getPrimaryKeyColumIndex(wantedFields,
              false);
      Assert.assertEquals(foundIndex, 12);
      foundIndex = ftsRestClient.getPrimaryKeyColumIndex(wantedFields,
              true);
      // 1+primary key index
      Assert.assertEquals(foundIndex, 13);
    } catch (Exception e)
    {
      e.printStackTrace();
      Assert.fail("Exception thrown while testing...");
    }
  }

  @Test(groups = { "Functional" })
  public void getDataColumnsFieldsAsCommaDelimitedString()
  {
    // to change when resources.tdbeacons_data_columns.txt is changed
    Collection<FTSDataColumnI> wantedFields = ftsRestClient
            .getAllDefaultDisplayedFTSDataColumns();
    String actual = ftsRestClient
            .getDataColumnsFieldsAsCommaDelimitedString(wantedFields);
    Assert.assertEquals(actual,
            "uniprot_start,uniprot_end,provider,model_identifier,model_category,model_title,resolution,confidence_avg_local_score,confidence_type,confidence_version,coverage,created,model_url");
  }

  @Test(groups = { "Functional" })
  public void getAllFTSDataColumns()
  {
    Collection<FTSDataColumnI> allFields = ftsRestClient
            .getAllFTSDataColumns();
    Assert.assertNotNull(allFields);
    // System.out.println(allFields.size());
    Assert.assertEquals(allFields.size(), 19);
  }

  @Test(groups = { "Functional" })
  public void getSearchableDataColumns()
  {
    // to change when resources.tdbeacons_data_columns.txt is changed
    Collection<FTSDataColumnI> searchableFields = ftsRestClient
            .getSearchableDataColumns();
    Assert.assertNotNull(searchableFields);
    // System.out.println(searchableFields.size());
    Assert.assertEquals(searchableFields.size(), 1); // only 1: uniprot
                                                     // accession
  }

  @Test(groups = { "Functional" })
  public void getPrimaryKeyColumn()
  {
    // to change when resources.tdbeacons_data_columns.txt is changed
    FTSDataColumnI expectedPKColumn;
    try
    {
      expectedPKColumn = ftsRestClient.getDataColumnByNameOrCode("Url");
      Assert.assertNotNull(ftsRestClient.getPrimaryKeyColumn());
      Assert.assertEquals(ftsRestClient.getPrimaryKeyColumn(),
              expectedPKColumn);
    } catch (Exception e)
    {
      e.printStackTrace();
      Assert.fail("Exception thrown while testing...");
    }
  }

  @Test(groups = { "Functional" })
  public void getDataColumnByNameOrCode()
  {
    try
    {
      FTSDataColumnI foundDataCol = ftsRestClient
              .getDataColumnByNameOrCode("uniprot_accession");
      Assert.assertNotNull(foundDataCol);
      Assert.assertEquals(foundDataCol.getName(), "UniProt Accession");
    } catch (Exception e)
    {
      e.printStackTrace();
      Assert.fail("Exception thrown while testing...");
    }
  }

  @Test(groups = { "Functional" })
  public void getDataColumnGroupById()
  {
    FTSDataColumnGroupI foundDataColGroup;
    try
    {
      foundDataColGroup = ftsRestClient.getDataColumnGroupById("g2");
      Assert.assertNotNull(foundDataColGroup);
      Assert.assertEquals(foundDataColGroup.getName(), "Quality");
    } catch (Exception e)
    {
      e.printStackTrace();
    }
  }

  @Test(groups = { "Functional" })
  public void getDefaultResponsePageSize()
  {
    int defaultResSize = ftsRestClient.getDefaultResponsePageSize();
    Assert.assertEquals(defaultResSize, 100); // why 100 or 500 ? pdb is 100,
                                              // uniprot 500
  }

  @Test(groups = { "Functional" })
  public void getColumnMinWidthTest()
  {
    try
    {
      FTSDataColumnI foundDataCol = ftsRestClient
              .getDataColumnByNameOrCode("uniprot_accession");
      Assert.assertNotNull(foundDataCol);
      int actualColMinWidth = foundDataCol.getMinWidth();
      Assert.assertEquals(actualColMinWidth, 50);
    } catch (Exception e)
    {
      e.printStackTrace();
      Assert.fail("Exception thrown while testing...");
    }
  }
  // could add test for MaxWidth & PreferedWith

  @Test(groups = { "Functional" })
  public void getColumnClassTest()
  {
    try
    {
      FTSDataColumnI foundDataCol = ftsRestClient
              .getDataColumnByNameOrCode("uniprot_accession");
      Assert.assertNotNull(foundDataCol);
      Assert.assertEquals(foundDataCol.getDataType().getDataTypeClass(),
              String.class);
      foundDataCol = ftsRestClient.getDataColumnByNameOrCode("id");
      Assert.assertNotNull(foundDataCol);
      Assert.assertEquals(foundDataCol.getDataType().getDataTypeClass(),
              String.class);
    } catch (Exception e)
    {
      e.printStackTrace();
      Assert.fail("Exception thrown while testing...");
    }
  }

  @Test(groups = { "Functional" })
  public void coverageForEqualsAndHashFunction()
  {
    Set<FTSDataColumnI> uniqueSet = new HashSet<FTSDataColumnI>();
    Collection<FTSDataColumnI> searchableCols = ftsRestClient
            .getSearchableDataColumns();
    System.out.println(searchableCols);
    for (FTSDataColumnI foundCol : searchableCols)
    {
      System.out.println(foundCol.toString());
      uniqueSet.add(foundCol);
      uniqueSet.add(foundCol);
    }
    Assert.assertTrue(!uniqueSet.isEmpty());
    // Assert.assertEquals(uniqueSet.size(), 22); -> 1 or 2 currently for 3DB
  }

  @Test(groups = { "Functional" })
  public void getTDBIdColumIndexTest()
  {
    List<FTSDataColumnI> wantedFields = new ArrayList<FTSDataColumnI>();
    try
    {
      wantedFields.add(TDBeaconsFTSRestClient.getInstance()
              .getDataColumnByNameOrCode("Model id"));
      wantedFields.add(TDBeaconsFTSRestClient.getInstance()
              .getDataColumnByNameOrCode("uniprot_accession"));
      wantedFields.add(TDBeaconsFTSRestClient.getInstance()
              .getDataColumnByNameOrCode("Title"));
    } catch (Exception e)
    {
      e.printStackTrace();
    }
    try
    {
      assertEquals(4, TDBeaconsFTSRestClient.getInstance()
              .getPrimaryKeyColumIndex(wantedFields, true));
      // assertEquals(3, TDBeaconsFTSRestClient.getInstance()
      // .getPrimaryKeyColumIndex(wantedFields, true));
    } catch (Exception e)
    {
      e.printStackTrace();
    }
  }

  private static String[][] mocks = { { "P38398.json",
      "{\"uniprot_entry\":{\"sequence_length\":1863,\"ac\":\"P38398\",\"id\":\"BRCA1_HUMAN\"},\"structures\":[{\"model_identifier\":\"4igk\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-12-17\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":1.75,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4igk_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4igk\"},{\"model_identifier\":\"1t15\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2004-04-15\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":1.85,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1t15_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1t15\"},{\"model_identifier\":\"4ifi\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-12-14\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":2.2,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ifi_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ifi\"},{\"model_identifier\":\"1t29\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2004-04-20\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":2.3,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1t29_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1t29\"},{\"model_identifier\":\"3pxb\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2010-12-09\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":2.5,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3pxb_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3pxb\"},{\"model_identifier\":\"4y2g\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-02-09\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":2.5,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4y2g_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4y2g\"},{\"model_identifier\":\"1y98\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2004-12-14\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":2.5,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1y98_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1y98\"},{\"model_identifier\":\"1jnx\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2001-07-26\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":2.5,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1jnx_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1jnx\"},{\"model_identifier\":\"3pxa\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2010-12-09\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":2.55,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3pxa_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3pxa\"},{\"model_identifier\":\"3k0h\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-24\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":2.7,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3k0h_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3k0h\"},{\"model_identifier\":\"3k0k\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-24\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":2.7,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3k0k_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3k0k\"},{\"model_identifier\":\"1n5o\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2002-11-06\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":2.8,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1n5o_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1n5o\"},{\"model_identifier\":\"3pxc\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2010-12-09\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":2.8,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3pxc_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3pxc\"},{\"model_identifier\":\"3pxd\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2010-12-09\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":2.8,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3pxd_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3pxd\"},{\"model_identifier\":\"1t2u\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2004-04-22\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":2.8,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1t2u_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1t2u\"},{\"model_identifier\":\"3k15\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-25\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":2.8,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3k15_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3k15\"},{\"model_identifier\":\"3pxe\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2010-12-09\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":2.85,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3pxe_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3pxe\"},{\"model_identifier\":\"3k16\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-25\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":3.0,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3k16_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3k16\"},{\"model_identifier\":\"4ofb\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-01-14\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":3.05,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ofb_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ofb\"},{\"model_identifier\":\"3coj\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2008-03-28\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":3.21,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3coj_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3coj\"},{\"model_identifier\":\"7lyb\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2021-03-06\",\"sequence_identity\":100.0,\"uniprot_start\":1,\"uniprot_end\":100,\"resolution\":3.28,\"coverage\":5.37,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/7lyb_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"ELECTRON MICROSCOPY\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/7lyb\"},{\"model_identifier\":\"1t2v\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2004-04-22\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":3.3,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1t2v_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1t2v\"},{\"model_identifier\":\"4y18\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-02-06\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":3.5,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4y18_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4y18\"},{\"model_identifier\":\"4jlu\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2013-03-13\",\"sequence_identity\":100.0,\"uniprot_start\":1649,\"uniprot_end\":1859,\"resolution\":3.5,\"coverage\":11.33,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4jlu_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4jlu\"},{\"model_identifier\":\"4u4a\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-07-23\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":3.51,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4u4a_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4u4a\"},{\"model_identifier\":\"2ing\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2006-10-07\",\"sequence_identity\":100.0,\"uniprot_start\":1649,\"uniprot_end\":1859,\"resolution\":3.6,\"coverage\":11.33,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2ing_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"X-RAY DIFFRACTION\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2ing\"},{\"model_identifier\":\"7jzv\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2020-09-02\",\"sequence_identity\":99.0,\"uniprot_start\":2,\"uniprot_end\":104,\"resolution\":3.9,\"coverage\":5.53,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/7jzv_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"ELECTRON MICROSCOPY\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/7jzv\"},{\"model_identifier\":\"6g2i\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2018-03-23\",\"sequence_identity\":100.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"resolution\":5.9,\"coverage\":11.49,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6g2i_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"ELECTRON MICROSCOPY\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6g2i\"},{\"model_identifier\":\"1jm7\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2001-07-17\",\"sequence_identity\":100.0,\"uniprot_start\":1,\"uniprot_end\":110,\"resolution\":null,\"coverage\":5.9,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1jm7_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"SOLUTION NMR\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1jm7\"},{\"model_identifier\":\"1oqa\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2003-03-07\",\"sequence_identity\":100.0,\"uniprot_start\":1755,\"uniprot_end\":1863,\"resolution\":null,\"coverage\":5.85,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1oqa_updated.cif\",\"model_format\":\"MMCIF\",\"experimental_method\":\"SOLUTION NMR\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1oqa\"},{\"model_identifier\":\"614057b7a2b5cc6a7fcb50bd\",\"model_category\":\"TEMPLATE-BASED\",\"provider\":\"SWISS-MODEL\",\"created\":\"2021-09-14\",\"sequence_identity\":1.0,\"uniprot_start\":1646,\"uniprot_end\":1859,\"coverage\":0.115,\"confidence_version\":\"4.2.0\",\"confidence_avg_local_score\":0.776,\"model_url\":\"https://swissmodel.expasy.org/3d-beacons/uniprot/P38398.pdb?range=1646-1859&template=6g2i.1.K&provider=swissmodel\",\"model_format\":\"PDB\",\"confidence_type\":\"QMEANDisCo\"},{\"model_identifier\":\"614057b7a2b5cc6a7fcb50c1\",\"model_category\":\"TEMPLATE-BASED\",\"provider\":\"SWISS-MODEL\",\"created\":\"2021-09-14\",\"sequence_identity\":1.0,\"uniprot_start\":1,\"uniprot_end\":103,\"coverage\":0.055,\"confidence_version\":\"4.2.0\",\"confidence_avg_local_score\":0.655,\"model_url\":\"https://swissmodel.expasy.org/3d-beacons/uniprot/P38398.pdb?range=1-103&template=1jm7.1.A&provider=swissmodel\",\"model_format\":\"PDB\",\"confidence_type\":\"QMEANDisCo\"},{\"model_identifier\":\"AF-P38398-F1\",\"model_category\":\"DEEP-LEARNING\",\"provider\":\"AlphaFold DB\",\"created\":\"2021-07-01\",\"sequence_identity\":1.0,\"uniprot_start\":1,\"uniprot_end\":1863,\"coverage\":100.0,\"model_url\":\"https://alphafold.ebi.ac.uk/files/AF-P38398-F1-model_v1.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://alphafold.ebi.ac.uk/entry/P38398\"}]}" },
      { "P01308.json",
"{\"uniprot_entry\":{\"sequence_length\":110,\"ac\":\"P01308\",\"id\":\"INS_HUMAN\"},\"structures\":[{\"model_identifier\":\"3w7y\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2013-03-11\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":0.92,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3w7y_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3w7y\"},{\"model_identifier\":\"3w7y\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2013-03-11\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":0.92,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3w7y_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3w7y\"},{\"model_identifier\":\"5e7w\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-10-13\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":0.9519,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5e7w_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5e7w\"},{\"model_identifier\":\"5e7w\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-10-13\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":0.9519,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5e7w_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5e7w\"},{\"model_identifier\":\"5hqi\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2016-01-21\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":0.97,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5hqi_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5hqi\"},{\"model_identifier\":\"5hqi\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2016-01-21\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":0.97,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5hqi_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5hqi\"},{\"model_identifier\":\"1mso\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2002-09-19\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.0,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1mso_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1mso\"},{\"model_identifier\":\"1mso\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2002-09-19\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.0,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1mso_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1mso\"},{\"model_identifier\":\"3hyd\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-06-22\",\"sequence_identity\":100.0,\"uniprot_start\":35,\"uniprot_end\":41,\"resolution\":1.0,\"coverage\":8.14,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3hyd_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3hyd\"},{\"model_identifier\":\"6ver\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2020-01-02\",\"sequence_identity\":91.0,\"uniprot_start\":25,\"uniprot_end\":46,\"resolution\":1.047,\"coverage\":25.58,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6ver_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6ver\"},{\"model_identifier\":\"6ver\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2020-01-02\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.047,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6ver_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6ver\"},{\"model_identifier\":\"4fka\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-06-13\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.08,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4fka_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4fka\"},{\"model_identifier\":\"4fka\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-06-13\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.08,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4fka_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4fka\"},{\"model_identifier\":\"3tt8\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2011-09-14\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.12,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3tt8_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3tt8\"},{\"model_identifier\":\"3tt8\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2011-09-14\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.12,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3tt8_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3tt8\"},{\"model_identifier\":\"3w7z\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2013-03-11\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.15,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3w7z_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3w7z\"},{\"model_identifier\":\"3w7z\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2013-03-11\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.15,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3w7z_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3w7z\"},{\"model_identifier\":\"5usp\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-02-13\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.174,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5usp_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5usp\"},{\"model_identifier\":\"5usp\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-02-13\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.174,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5usp_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5usp\"},{\"model_identifier\":\"5uoz\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-02-01\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.17463871031,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5uoz_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5uoz\"},{\"model_identifier\":\"5uoz\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-02-01\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.17463871031,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5uoz_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5uoz\"},{\"model_identifier\":\"5urt\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-02-12\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.18,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5urt_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5urt\"},{\"model_identifier\":\"5urt\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-02-12\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.18,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5urt_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5urt\"},{\"model_identifier\":\"1g7a\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2000-11-09\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.2,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1g7a_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1g7a\"},{\"model_identifier\":\"4ajx\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-02-20\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":1.2,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ajx_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ajx\"},{\"model_identifier\":\"1g7a\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2000-11-09\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.2,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1g7a_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1g7a\"},{\"model_identifier\":\"4ajx\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-02-20\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.2,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ajx_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ajx\"},{\"model_identifier\":\"5uu2\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-02-15\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.223,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5uu2_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5uu2\"},{\"model_identifier\":\"5uu2\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-02-15\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.223,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5uu2_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5uu2\"},{\"model_identifier\":\"6gv0\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2018-06-20\",\"sequence_identity\":93.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.26,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6gv0_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6gv0\"},{\"model_identifier\":\"6gv0\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2018-06-20\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.26,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6gv0_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6gv0\"},{\"model_identifier\":\"5hrq\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2016-01-24\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.28,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5hrq_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5hrq\"},{\"model_identifier\":\"5hrq\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2016-01-24\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.28,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5hrq_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5hrq\"},{\"model_identifier\":\"1g7b\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2000-11-09\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.3,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1g7b_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1g7b\"},{\"model_identifier\":\"5usv\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-02-14\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.3,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5usv_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5usv\"},{\"model_identifier\":\"3bxq\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2008-01-14\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.3,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3bxq_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3bxq\"},{\"model_identifier\":\"1g7b\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2000-11-09\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.3,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1g7b_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1g7b\"},{\"model_identifier\":\"5usv\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-02-14\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.3,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5usv_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5usv\"},{\"model_identifier\":\"3bxq\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2008-01-14\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.3,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3bxq_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3bxq\"},{\"model_identifier\":\"5uqa\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-02-07\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.31000248093,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5uqa_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5uqa\"},{\"model_identifier\":\"5uqa\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-02-07\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.31000248093,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5uqa_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5uqa\"},{\"model_identifier\":\"5hpr\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2016-01-21\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.33,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5hpr_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5hpr\"},{\"model_identifier\":\"5hpr\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2016-01-21\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.33,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5hpr_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5hpr\"},{\"model_identifier\":\"5udp\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2016-12-28\",\"sequence_identity\":93.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.348,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5udp_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5udp\"},{\"model_identifier\":\"5udp\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2016-12-28\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.348,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5udp_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5udp\"},{\"model_identifier\":\"3fq9\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-01-07\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.35,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3fq9_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3fq9\"},{\"model_identifier\":\"5ena\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-11-09\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.35,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5ena_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5ena\"},{\"model_identifier\":\"3exx\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2008-10-17\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.35,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3exx_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3exx\"},{\"model_identifier\":\"6s34\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-06-24\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.35,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6s34_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6s34\"},{\"model_identifier\":\"5ena\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-11-09\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.35,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5ena_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5ena\"},{\"model_identifier\":\"3exx\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2008-10-17\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.35,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3exx_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3exx\"},{\"model_identifier\":\"6s34\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-06-24\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.35,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6s34_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6s34\"},{\"model_identifier\":\"3fq9\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-01-07\",\"sequence_identity\":95.0,\"uniprot_start\":91,\"uniprot_end\":110,\"resolution\":1.35,\"coverage\":23.26,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3fq9_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3fq9\"},{\"model_identifier\":\"6tc2\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-11-04\",\"sequence_identity\":100.0,\"uniprot_start\":1,\"uniprot_end\":110,\"resolution\":1.36,\"coverage\":100.0,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6tc2_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6tc2\"},{\"model_identifier\":\"2omh\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-01-22\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.36,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2omh_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2omh\"},{\"model_identifier\":\"2omh\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-01-22\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.36,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2omh_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2omh\"},{\"model_identifier\":\"4nib\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2013-11-05\",\"sequence_identity\":93.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.4,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4nib_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4nib\"},{\"model_identifier\":\"4cy7\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-04-10\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.4,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4cy7_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4cy7\"},{\"model_identifier\":\"3w80\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2013-03-11\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.4,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3w80_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3w80\"},{\"model_identifier\":\"1ben\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1996-02-15\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.4,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1ben_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1ben\"},{\"model_identifier\":\"7nhu\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2021-02-11\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":1.4,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/7nhu_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/7nhu\"},{\"model_identifier\":\"4nib\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2013-11-05\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.4,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4nib_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4nib\"},{\"model_identifier\":\"4cy7\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-04-10\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.4,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4cy7_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4cy7\"},{\"model_identifier\":\"7nhu\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2021-02-11\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.4,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/7nhu_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/7nhu\"},{\"model_identifier\":\"3w80\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2013-03-11\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.4,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3w80_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3w80\"},{\"model_identifier\":\"1ben\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1996-02-15\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.4,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1ben_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1ben\"},{\"model_identifier\":\"6vet\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2020-01-02\",\"sequence_identity\":91.0,\"uniprot_start\":25,\"uniprot_end\":46,\"resolution\":1.46,\"coverage\":25.58,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6vet_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6vet\"},{\"model_identifier\":\"6vet\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2020-01-02\",\"sequence_identity\":90.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.46,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6vet_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6vet\"},{\"model_identifier\":\"4ey1\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-01\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.471,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ey1_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ey1\"},{\"model_identifier\":\"4ey9\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-01\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.471,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ey9_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ey9\"},{\"model_identifier\":\"4eyd\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-01\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.471,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4eyd_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4eyd\"},{\"model_identifier\":\"4ey1\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-01\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.471,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ey1_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ey1\"},{\"model_identifier\":\"4ey9\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-01\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.471,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ey9_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ey9\"},{\"model_identifier\":\"4eyd\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-01\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.471,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4eyd_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4eyd\"},{\"model_identifier\":\"4xc4\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-12-17\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.499,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4xc4_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4xc4\"},{\"model_identifier\":\"4xc4\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-12-17\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.499,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4xc4_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4xc4\"},{\"model_identifier\":\"1zeh\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1998-05-01\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.5,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1zeh_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1zeh\"},{\"model_identifier\":\"2wrx\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-02\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.5,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2wrx_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2wrx\"},{\"model_identifier\":\"2ws6\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-03\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.5,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2ws6_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2ws6\"},{\"model_identifier\":\"2ws6\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-03\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.5,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2ws6_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2ws6\"},{\"model_identifier\":\"4cxl\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-04-07\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.5,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4cxl_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4cxl\"},{\"model_identifier\":\"5en9\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-11-09\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.5,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5en9_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5en9\"},{\"model_identifier\":\"4p65\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-03-21\",\"sequence_identity\":93.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.5,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4p65_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4p65\"},{\"model_identifier\":\"2c8r\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2005-12-06\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":1.5,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2c8r_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2c8r\"},{\"model_identifier\":\"6s4j\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-06-28\",\"sequence_identity\":93.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":1.5,\"coverage\":32.56,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6s4j_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6s4j\"},{\"model_identifier\":\"1zeh\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1998-05-01\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.5,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1zeh_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1zeh\"},{\"model_identifier\":\"2wrx\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-02\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.5,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2wrx_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2wrx\"},{\"model_identifier\":\"2ws6\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-03\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.5,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2ws6_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2ws6\"},{\"model_identifier\":\"2c8r\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2005-12-06\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.5,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2c8r_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2c8r\"},{\"model_identifier\":\"4cxl\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-04-07\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.5,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4cxl_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4cxl\"},{\"model_identifier\":\"5en9\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-11-09\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.5,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5en9_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5en9\"},{\"model_identifier\":\"4p65\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-03-21\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.5,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4p65_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4p65\"},{\"model_identifier\":\"6s4j\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-06-28\",\"sequence_identity\":95.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.5,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6s4j_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6s4j\"},{\"model_identifier\":\"6s4i\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-06-28\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":1.511,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6s4i_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6s4i\"},{\"model_identifier\":\"6s4i\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-06-28\",\"sequence_identity\":95.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.511,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6s4i_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6s4i\"},{\"model_identifier\":\"2omg\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-01-22\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.52,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2omg_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2omg\"},{\"model_identifier\":\"2omg\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-01-22\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.52,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2omg_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2omg\"},{\"model_identifier\":\"4eyn\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-01\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.532,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4eyn_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4eyn\"},{\"model_identifier\":\"4eyn\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-01\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.532,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4eyn_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4eyn\"},{\"model_identifier\":\"5bqq\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-05-29\",\"sequence_identity\":96.0,\"uniprot_start\":25,\"uniprot_end\":52,\"resolution\":1.54,\"coverage\":32.56,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5bqq_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5bqq\"},{\"model_identifier\":\"5bqq\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-05-29\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.54,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5bqq_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5bqq\"},{\"model_identifier\":\"4exx\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-01\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.55,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4exx_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4exx\"},{\"model_identifier\":\"5t7r\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2016-09-05\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.55,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5t7r_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5t7r\"},{\"model_identifier\":\"4exx\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-01\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.55,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4exx_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4exx\"},{\"model_identifier\":\"5t7r\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2016-09-05\",\"sequence_identity\":90.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.55,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5t7r_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5t7r\"},{\"model_identifier\":\"2wru\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-02\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":49,\"resolution\":1.57,\"coverage\":29.07,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2wru_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2wru\"},{\"model_identifier\":\"2wru\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-02\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.57,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2wru_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2wru\"},{\"model_identifier\":\"6o17\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-02-18\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":1.58,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6o17_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6o17\"},{\"model_identifier\":\"6o17\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-02-18\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.58,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6o17_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6o17\"},{\"model_identifier\":\"4une\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-05-28\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.59,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4une_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4une\"},{\"model_identifier\":\"4une\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-05-28\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.59,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4une_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4une\"},{\"model_identifier\":\"4eyp\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-01\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.591,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4eyp_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4eyp\"},{\"model_identifier\":\"4f1b\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-06\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.591,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f1b_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f1b\"},{\"model_identifier\":\"4eyp\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-01\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.591,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4eyp_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4eyp\"},{\"model_identifier\":\"4f1b\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-06\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.591,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f1b_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f1b\"},{\"model_identifier\":\"1zeg\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1998-05-01\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.6,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1zeg_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1zeg\"},{\"model_identifier\":\"2ws1\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-03\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.6,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2ws1_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2ws1\"},{\"model_identifier\":\"3zu1\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2011-07-13\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.6,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3zu1_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3zu1\"},{\"model_identifier\":\"1trz\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1993-11-19\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.6,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1trz_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1trz\"},{\"model_identifier\":\"4iuz\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2013-01-22\",\"sequence_identity\":90.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.6,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4iuz_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4iuz\"},{\"model_identifier\":\"3i3z\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-07-01\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":1.6,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3i3z_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3i3z\"},{\"model_identifier\":\"1uz9\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2004-03-08\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":1.6,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1uz9_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1uz9\"},{\"model_identifier\":\"3e7y\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2008-08-19\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":1.6,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3e7y_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3e7y\"},{\"model_identifier\":\"3i3z\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-07-01\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.6,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3i3z_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3i3z\"},{\"model_identifier\":\"1zeg\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1998-05-01\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.6,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1zeg_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1zeg\"},{\"model_identifier\":\"2ws1\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-03\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.6,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2ws1_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2ws1\"},{\"model_identifier\":\"1uz9\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2004-03-08\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.6,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1uz9_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1uz9\"},{\"model_identifier\":\"3zu1\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2011-07-13\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.6,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3zu1_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3zu1\"},{\"model_identifier\":\"3e7y\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2008-08-19\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.6,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3e7y_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3e7y\"},{\"model_identifier\":\"1trz\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1993-11-19\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.6,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1trz_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1trz\"},{\"model_identifier\":\"4iuz\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2013-01-22\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.6,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4iuz_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4iuz\"},{\"model_identifier\":\"6tyh\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-08-08\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.60001899481,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6tyh_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6tyh\"},{\"model_identifier\":\"6tyh\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-08-08\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.60001899481,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6tyh_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6tyh\"},{\"model_identifier\":\"6nwv\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-02-07\",\"sequence_identity\":93.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.601,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6nwv_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6nwv\"},{\"model_identifier\":\"6nwv\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-02-07\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.601,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6nwv_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6nwv\"},{\"model_identifier\":\"1guj\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2002-01-28\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.62,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1guj_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1guj\"},{\"model_identifier\":\"1guj\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2002-01-28\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.62,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1guj_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1guj\"},{\"model_identifier\":\"4f1d\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-06\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.637,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f1d_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f1d\"},{\"model_identifier\":\"4f1g\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-06\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.637,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f1g_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f1g\"},{\"model_identifier\":\"4f4t\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-11\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.637,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f4t_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f4t\"},{\"model_identifier\":\"4f4v\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-11\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.637,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f4v_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f4v\"},{\"model_identifier\":\"4f51\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-11\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.637,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f51_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f51\"},{\"model_identifier\":\"4f1d\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-06\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.637,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f1d_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f1d\"},{\"model_identifier\":\"4f1g\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-06\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.637,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f1g_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f1g\"},{\"model_identifier\":\"4f4t\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-11\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.637,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f4t_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f4t\"},{\"model_identifier\":\"4f4v\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-11\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.637,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f4v_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f4v\"},{\"model_identifier\":\"4f51\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-11\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.637,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f51_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f51\"},{\"model_identifier\":\"4ex1\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-04-29\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.657,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ex1_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ex1\"},{\"model_identifier\":\"4ex1\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-04-29\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.657,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ex1_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ex1\"},{\"model_identifier\":\"4iyd\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2013-01-28\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":1.66,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4iyd_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4iyd\"},{\"model_identifier\":\"4iyd\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2013-01-28\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":109,\"resolution\":1.66,\"coverage\":23.26,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4iyd_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4iyd\"},{\"model_identifier\":\"3utq\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2011-11-26\",\"sequence_identity\":100.0,\"uniprot_start\":15,\"uniprot_end\":24,\"resolution\":1.67,\"coverage\":0.0,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3utq_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3utq\"},{\"model_identifier\":\"4f0o\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-04\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.672,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f0o_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f0o\"},{\"model_identifier\":\"4f0o\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-04\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.672,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f0o_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f0o\"},{\"model_identifier\":\"4f8f\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-17\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.676,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f8f_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f8f\"},{\"model_identifier\":\"4f8f\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-17\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.676,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f8f_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f8f\"},{\"model_identifier\":\"4f0n\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-04\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.679,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f0n_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f0n\"},{\"model_identifier\":\"4f0n\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-04\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.679,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f0n_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f0n\"},{\"model_identifier\":\"5c0d\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-06-12\",\"sequence_identity\":90.0,\"uniprot_start\":15,\"uniprot_end\":24,\"resolution\":1.68,\"coverage\":0.0,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5c0d_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5c0d\"},{\"model_identifier\":\"4f1f\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-06\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.684,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f1f_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f1f\"},{\"model_identifier\":\"4f1f\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-06\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.684,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f1f_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f1f\"},{\"model_identifier\":\"3zi3\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2013-01-02\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.7,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3zi3_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3zi3\"},{\"model_identifier\":\"4f1c\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-06\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.7,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f1c_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f1c\"},{\"model_identifier\":\"4cxn\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-04-07\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.7,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4cxn_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4cxn\"},{\"model_identifier\":\"5cny\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-07-18\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.7,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5cny_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5cny\"},{\"model_identifier\":\"5co2\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-07-19\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.7,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5co2_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5co2\"},{\"model_identifier\":\"2oly\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-01-20\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.7,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2oly_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2oly\"},{\"model_identifier\":\"2olz\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-01-20\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.7,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2olz_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2olz\"},{\"model_identifier\":\"5boq\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-05-27\",\"sequence_identity\":93.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.7,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5boq_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5boq\"},{\"model_identifier\":\"5viz\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-04-17\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":1.7,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5viz_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5viz\"},{\"model_identifier\":\"3e7z\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2008-08-19\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":1.7,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3e7z_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3e7z\"},{\"model_identifier\":\"3zi3\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2013-01-02\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.7,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3zi3_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3zi3\"},{\"model_identifier\":\"4f1c\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-06\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.7,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f1c_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f1c\"},{\"model_identifier\":\"4cxn\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-04-07\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.7,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4cxn_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4cxn\"},{\"model_identifier\":\"5cny\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-07-18\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.7,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5cny_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5cny\"},{\"model_identifier\":\"3e7z\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2008-08-19\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.7,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3e7z_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3e7z\"},{\"model_identifier\":\"5co2\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-07-19\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.7,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5co2_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5co2\"},{\"model_identifier\":\"2oly\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-01-20\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.7,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2oly_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2oly\"},{\"model_identifier\":\"2olz\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-01-20\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.7,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2olz_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2olz\"},{\"model_identifier\":\"5boq\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-05-27\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.7,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5boq_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5boq\"},{\"model_identifier\":\"5viz\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-04-17\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":109,\"resolution\":1.7,\"coverage\":23.26,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5viz_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5viz\"},{\"model_identifier\":\"4rxw\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-12-12\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.73,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4rxw_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4rxw\"},{\"model_identifier\":\"4rxw\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-12-12\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.73,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4rxw_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4rxw\"},{\"model_identifier\":\"5bts\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-06-03\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.77,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5bts_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5bts\"},{\"model_identifier\":\"5bts\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-06-03\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.77,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5bts_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5bts\"},{\"model_identifier\":\"4gbc\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-07-27\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.778,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4gbc_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4gbc\"},{\"model_identifier\":\"4gbc\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-07-27\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.778,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4gbc_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4gbc\"},{\"model_identifier\":\"1ev3\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2000-04-19\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.78,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1ev3_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1ev3\"},{\"model_identifier\":\"1ev3\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2000-04-19\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.78,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1ev3_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1ev3\"},{\"model_identifier\":\"4ewz\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-04-29\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.791,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ewz_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ewz\"},{\"model_identifier\":\"4ewz\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-04-29\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.791,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ewz_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ewz\"},{\"model_identifier\":\"4f1a\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-06\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.8,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f1a_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f1a\"},{\"model_identifier\":\"2vjz\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-12-14\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.8,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2vjz_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2vjz\"},{\"model_identifier\":\"1rwe\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2003-12-16\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.8,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1rwe_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1rwe\"},{\"model_identifier\":\"5co6\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-07-19\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.8,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5co6_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5co6\"},{\"model_identifier\":\"6p4z\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-05-29\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.8,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6p4z_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6p4z\"},{\"model_identifier\":\"1xda\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1996-12-18\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":1.8,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1xda_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1xda\"},{\"model_identifier\":\"4ajz\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-02-21\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":1.8,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ajz_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ajz\"},{\"model_identifier\":\"4iyf\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2013-01-28\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":1.8,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4iyf_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4iyf\"},{\"model_identifier\":\"2ceu\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2006-02-10\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":49,\"resolution\":1.8,\"coverage\":29.07,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2ceu_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2ceu\"},{\"model_identifier\":\"4f1a\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-05-06\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.8,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4f1a_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4f1a\"},{\"model_identifier\":\"2ceu\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2006-02-10\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.8,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2ceu_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2ceu\"},{\"model_identifier\":\"2vjz\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-12-14\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.8,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2vjz_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2vjz\"},{\"model_identifier\":\"1rwe\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2003-12-16\",\"sequence_identity\":95.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.8,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1rwe_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1rwe\"},{\"model_identifier\":\"1xda\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1996-12-18\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.8,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1xda_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1xda\"},{\"model_identifier\":\"5co6\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-07-19\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.8,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5co6_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5co6\"},{\"model_identifier\":\"4ajz\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-02-21\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.8,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ajz_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ajz\"},{\"model_identifier\":\"6p4z\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-05-29\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.8,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6p4z_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6p4z\"},{\"model_identifier\":\"4iyf\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2013-01-28\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":109,\"resolution\":1.8,\"coverage\":23.26,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4iyf_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4iyf\"},{\"model_identifier\":\"4ung\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-05-28\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.81,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ung_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ung\"},{\"model_identifier\":\"4ung\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-05-28\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.81,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ung_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ung\"},{\"model_identifier\":\"6h3m\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2018-07-19\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.821,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6h3m_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6h3m\"},{\"model_identifier\":\"6h3m\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2018-07-19\",\"sequence_identity\":90.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.821,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6h3m_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6h3m\"},{\"model_identifier\":\"3inc\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-08-12\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.85,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3inc_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3inc\"},{\"model_identifier\":\"3i40\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-07-01\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":1.85,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3i40_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3i40\"},{\"model_identifier\":\"6ves\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2020-01-02\",\"sequence_identity\":95.0,\"uniprot_start\":25,\"uniprot_end\":46,\"resolution\":1.85,\"coverage\":25.58,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6ves_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6ves\"},{\"model_identifier\":\"3i40\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-07-01\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.85,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3i40_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3i40\"},{\"model_identifier\":\"6ves\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2020-01-02\",\"sequence_identity\":90.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.85,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6ves_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6ves\"},{\"model_identifier\":\"3inc\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-08-12\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.85,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3inc_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3inc\"},{\"model_identifier\":\"4z77\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-04-06\",\"sequence_identity\":89.0,\"uniprot_start\":39,\"uniprot_end\":47,\"resolution\":1.85,\"coverage\":10.47,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4z77_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4z77\"},{\"model_identifier\":\"4ex0\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-04-29\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.86,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ex0_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ex0\"},{\"model_identifier\":\"4ex0\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-04-29\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.86,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ex0_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ex0\"},{\"model_identifier\":\"4gbn\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-07-27\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.872,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4gbn_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4gbn\"},{\"model_identifier\":\"4gbn\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-07-27\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.872,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4gbn_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4gbn\"},{\"model_identifier\":\"5mt9\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-01-07\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.88,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5mt9_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5mt9\"},{\"model_identifier\":\"5mt9\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-01-07\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.88,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5mt9_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5mt9\"},{\"model_identifier\":\"4z76\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-04-06\",\"sequence_identity\":89.0,\"uniprot_start\":39,\"uniprot_end\":47,\"resolution\":1.88,\"coverage\":10.47,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4z76_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4z76\"},{\"model_identifier\":\"3ilg\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-08-07\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.9,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3ilg_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3ilg\"},{\"model_identifier\":\"3zqr\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2011-06-10\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.9,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3zqr_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3zqr\"},{\"model_identifier\":\"3kq6\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-11-17\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.9,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3kq6_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3kq6\"},{\"model_identifier\":\"1ev6\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2000-04-19\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.9,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1ev6_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1ev6\"},{\"model_identifier\":\"1evr\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2000-04-20\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.9,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1evr_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1evr\"},{\"model_identifier\":\"1tyl\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1994-06-21\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.9,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1tyl_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1tyl\"},{\"model_identifier\":\"1tym\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1994-06-21\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.9,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1tym_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1tym\"},{\"model_identifier\":\"5bpo\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-05-28\",\"sequence_identity\":93.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.9,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5bpo_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5bpo\"},{\"model_identifier\":\"1htv\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2001-01-01\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":51,\"resolution\":1.9,\"coverage\":31.4,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1htv_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1htv\"},{\"model_identifier\":\"2ws4\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-03\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":49,\"resolution\":1.9,\"coverage\":29.07,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2ws4_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2ws4\"},{\"model_identifier\":\"1htv\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2001-01-01\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.9,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1htv_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1htv\"},{\"model_identifier\":\"2ws4\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-03\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.9,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2ws4_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2ws4\"},{\"model_identifier\":\"3ilg\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-08-07\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.9,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3ilg_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3ilg\"},{\"model_identifier\":\"3zqr\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2011-06-10\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.9,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3zqr_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3zqr\"},{\"model_identifier\":\"3kq6\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-11-17\",\"sequence_identity\":90.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.9,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3kq6_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3kq6\"},{\"model_identifier\":\"1ev6\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2000-04-19\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.9,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1ev6_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1ev6\"},{\"model_identifier\":\"1evr\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2000-04-20\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.9,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1evr_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1evr\"},{\"model_identifier\":\"1tyl\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1994-06-21\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.9,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1tyl_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1tyl\"},{\"model_identifier\":\"1tym\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1994-06-21\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.9,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1tym_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1tym\"},{\"model_identifier\":\"5bpo\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-05-28\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.9,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5bpo_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5bpo\"},{\"model_identifier\":\"5co9\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-07-20\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.92,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5co9_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5co9\"},{\"model_identifier\":\"5co9\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-07-20\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.92,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5co9_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5co9\"},{\"model_identifier\":\"1os3\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2003-03-18\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.95,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1os3_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1os3\"},{\"model_identifier\":\"2c8q\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2005-12-06\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":1.95,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2c8q_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2c8q\"},{\"model_identifier\":\"2c8q\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2005-12-06\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.95,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2c8q_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2c8q\"},{\"model_identifier\":\"1os3\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2003-03-18\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.95,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1os3_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1os3\"},{\"model_identifier\":\"2om1\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-01-20\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.97,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2om1_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2om1\"},{\"model_identifier\":\"3zs2\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2011-06-21\",\"sequence_identity\":87.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.97,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3zs2_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3zs2\"},{\"model_identifier\":\"2om1\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-01-20\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.97,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2om1_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2om1\"},{\"model_identifier\":\"3zs2\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2011-06-21\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.97,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3zs2_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3zs2\"},{\"model_identifier\":\"5uu4\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-02-16\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":1.973,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5uu4_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5uu4\"},{\"model_identifier\":\"5uu4\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-02-16\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.973,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5uu4_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5uu4\"},{\"model_identifier\":\"3u4n\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2011-10-10\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":1.98,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3u4n_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3u4n\"},{\"model_identifier\":\"4efx\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-03-30\",\"sequence_identity\":96.0,\"uniprot_start\":25,\"uniprot_end\":52,\"resolution\":1.98,\"coverage\":32.56,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4efx_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4efx\"},{\"model_identifier\":\"3u4n\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2011-10-10\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.98,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3u4n_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3u4n\"},{\"model_identifier\":\"4efx\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-03-30\",\"sequence_identity\":95.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":1.98,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4efx_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4efx\"},{\"model_identifier\":\"1q4v\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2003-08-04\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.0,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1q4v_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1q4v\"},{\"model_identifier\":\"3p2x\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2010-10-04\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.0,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3p2x_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3p2x\"},{\"model_identifier\":\"2qiu\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-07-05\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.0,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2qiu_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2qiu\"},{\"model_identifier\":\"3v19\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2011-12-09\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.0,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3v19_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3v19\"},{\"model_identifier\":\"1j73\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2001-05-15\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.0,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1j73_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1j73\"},{\"model_identifier\":\"1qiz\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1999-06-18\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.0,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1qiz_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1qiz\"},{\"model_identifier\":\"1znj\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1997-09-23\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.0,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1znj_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1znj\"},{\"model_identifier\":\"2r36\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-08-29\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.0,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2r36_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2r36\"},{\"model_identifier\":\"2w44\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2008-11-21\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":2.0,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2w44_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2w44\"},{\"model_identifier\":\"2qiu\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-07-05\",\"sequence_identity\":100.0,\"uniprot_start\":89,\"uniprot_end\":110,\"resolution\":2.0,\"coverage\":25.58,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2qiu_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2qiu\"},{\"model_identifier\":\"2r36\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-08-29\",\"sequence_identity\":100.0,\"uniprot_start\":89,\"uniprot_end\":110,\"resolution\":2.0,\"coverage\":25.58,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2r36_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2r36\"},{\"model_identifier\":\"1q4v\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2003-08-04\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.0,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1q4v_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1q4v\"},{\"model_identifier\":\"3p2x\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2010-10-04\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.0,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3p2x_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3p2x\"},{\"model_identifier\":\"3v19\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2011-12-09\",\"sequence_identity\":86.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.0,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3v19_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3v19\"},{\"model_identifier\":\"1j73\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2001-05-15\",\"sequence_identity\":95.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.0,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1j73_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1j73\"},{\"model_identifier\":\"1qiz\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1999-06-18\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.0,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1qiz_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1qiz\"},{\"model_identifier\":\"1znj\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1997-09-23\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.0,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1znj_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1znj\"},{\"model_identifier\":\"2w44\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2008-11-21\",\"sequence_identity\":100.0,\"uniprot_start\":94,\"uniprot_end\":110,\"resolution\":2.0,\"coverage\":19.77,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2w44_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2w44\"},{\"model_identifier\":\"2omq\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-01-22\",\"sequence_identity\":100.0,\"uniprot_start\":36,\"uniprot_end\":41,\"resolution\":2.0,\"coverage\":6.98,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2omq_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2omq\"},{\"model_identifier\":\"4fg3\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-06-02\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.001,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4fg3_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4fg3\"},{\"model_identifier\":\"4fg3\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-06-02\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.001,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4fg3_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4fg3\"},{\"model_identifier\":\"4akj\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-02-23\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":2.01,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4akj_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4akj\"},{\"model_identifier\":\"4akj\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-02-23\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.01,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4akj_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4akj\"},{\"model_identifier\":\"5mt3\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-01-06\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.02,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5mt3_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5mt3\"},{\"model_identifier\":\"5mt3\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-01-06\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.02,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5mt3_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5mt3\"},{\"model_identifier\":\"2om0\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-01-20\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.05,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2om0_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2om0\"},{\"model_identifier\":\"3q6e\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2010-12-31\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.05,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3q6e_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3q6e\"},{\"model_identifier\":\"2om0\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-01-20\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.05,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2om0_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2om0\"},{\"model_identifier\":\"3q6e\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2010-12-31\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.05,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3q6e_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3q6e\"},{\"model_identifier\":\"5uss\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-02-13\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.061,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5uss_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5uss\"},{\"model_identifier\":\"5uss\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-02-13\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.061,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5uss_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5uss\"},{\"model_identifier\":\"1w8p\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2004-09-24\",\"sequence_identity\":93.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.08,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1w8p_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1w8p\"},{\"model_identifier\":\"2r35\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-08-29\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.08,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2r35_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2r35\"},{\"model_identifier\":\"2r35\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-08-29\",\"sequence_identity\":100.0,\"uniprot_start\":89,\"uniprot_end\":110,\"resolution\":2.08,\"coverage\":25.58,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2r35_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2r35\"},{\"model_identifier\":\"1w8p\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2004-09-24\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.08,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1w8p_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1w8p\"},{\"model_identifier\":\"2ws0\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-03\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.1,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2ws0_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2ws0\"},{\"model_identifier\":\"2ws0\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-03\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.1,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2ws0_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2ws0\"},{\"model_identifier\":\"2wrv\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-02\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":49,\"resolution\":2.15,\"coverage\":29.07,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2wrv_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2wrv\"},{\"model_identifier\":\"2wrv\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-02\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.15,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2wrv_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2wrv\"},{\"model_identifier\":\"6z7y\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2020-06-02\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.2,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6z7y_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6z7y\"},{\"model_identifier\":\"5mam\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2016-11-03\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.2,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5mam_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5mam\"},{\"model_identifier\":\"3v1g\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2011-12-09\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.2,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3v1g_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3v1g\"},{\"model_identifier\":\"2vk0\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-12-14\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.2,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2vk0_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2vk0\"},{\"model_identifier\":\"3ir0\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-08-21\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.2,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3ir0_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3ir0\"},{\"model_identifier\":\"5hpu\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2016-01-21\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.2,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5hpu_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5hpu\"},{\"model_identifier\":\"2g56\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2006-02-22\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.2,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2g56_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2g56\"},{\"model_identifier\":\"6gnq\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2018-05-31\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.2,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6gnq_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6gnq\"},{\"model_identifier\":\"6z7y\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2020-06-02\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.2,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6z7y_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6z7y\"},{\"model_identifier\":\"5mam\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2016-11-03\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.2,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5mam_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5mam\"},{\"model_identifier\":\"3v1g\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2011-12-09\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.2,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3v1g_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3v1g\"},{\"model_identifier\":\"2vk0\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-12-14\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.2,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2vk0_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2vk0\"},{\"model_identifier\":\"3ir0\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-08-21\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.2,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3ir0_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3ir0\"},{\"model_identifier\":\"5hpu\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2016-01-21\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.2,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5hpu_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5hpu\"},{\"model_identifier\":\"6gnq\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2018-05-31\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.2,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6gnq_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6gnq\"},{\"model_identifier\":\"4ewx\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-04-28\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.201,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ewx_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ewx\"},{\"model_identifier\":\"4ewx\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-04-28\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.201,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ewx_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ewx\"},{\"model_identifier\":\"2omi\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-01-22\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.24,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2omi_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2omi\"},{\"model_identifier\":\"2omi\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-01-22\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.24,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2omi_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2omi\"},{\"model_identifier\":\"5uu3\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-02-16\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.25,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5uu3_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5uu3\"},{\"model_identifier\":\"1os4\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2003-03-18\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.25,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1os4_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1os4\"},{\"model_identifier\":\"2g54\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2006-02-22\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.25,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2g54_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2g54\"},{\"model_identifier\":\"6ck2\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2018-02-27\",\"sequence_identity\":93.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.25,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6ck2_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6ck2\"},{\"model_identifier\":\"2r34\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-08-29\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.25,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2r34_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2r34\"},{\"model_identifier\":\"2r34\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-08-29\",\"sequence_identity\":100.0,\"uniprot_start\":89,\"uniprot_end\":110,\"resolution\":2.25,\"coverage\":25.58,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2r34_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2r34\"},{\"model_identifier\":\"5uu3\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-02-16\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.25,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5uu3_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5uu3\"},{\"model_identifier\":\"1os4\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2003-03-18\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.25,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1os4_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1os4\"},{\"model_identifier\":\"6ck2\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2018-02-27\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.25,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6ck2_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6ck2\"},{\"model_identifier\":\"4ak0\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-02-21\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":2.28,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ak0_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ak0\"},{\"model_identifier\":\"4ak0\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-02-21\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.28,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4ak0_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4ak0\"},{\"model_identifier\":\"3p33\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2010-10-04\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.3,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3p33_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3p33\"},{\"model_identifier\":\"5ems\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-11-06\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.3,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5ems_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5ems\"},{\"model_identifier\":\"1qiy\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1999-06-18\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.3,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1qiy_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1qiy\"},{\"model_identifier\":\"1lph\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1995-04-19\",\"sequence_identity\":93.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.3,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1lph_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1lph\"},{\"model_identifier\":\"3rov\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2011-04-26\",\"sequence_identity\":87.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.3,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3rov_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3rov\"},{\"model_identifier\":\"4eww\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-04-28\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.3,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4eww_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4eww\"},{\"model_identifier\":\"1xw7\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2004-10-29\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.3,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1xw7_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1xw7\"},{\"model_identifier\":\"3p33\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2010-10-04\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.3,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3p33_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3p33\"},{\"model_identifier\":\"5ems\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-11-06\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.3,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5ems_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5ems\"},{\"model_identifier\":\"1qiy\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1999-06-18\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.3,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1qiy_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1qiy\"},{\"model_identifier\":\"1lph\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1995-04-19\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.3,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1lph_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1lph\"},{\"model_identifier\":\"3rov\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2011-04-26\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.3,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3rov_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3rov\"},{\"model_identifier\":\"4eww\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-04-28\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.3,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4eww_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4eww\"},{\"model_identifier\":\"1xw7\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2004-10-29\",\"sequence_identity\":95.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.3,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1xw7_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1xw7\"},{\"model_identifier\":\"4z78\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-04-06\",\"sequence_identity\":100.0,\"uniprot_start\":39,\"uniprot_end\":48,\"resolution\":2.304,\"coverage\":11.63,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4z78_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4z78\"},{\"model_identifier\":\"4wdi\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-09-08\",\"sequence_identity\":100.0,\"uniprot_start\":39,\"uniprot_end\":47,\"resolution\":2.313,\"coverage\":10.47,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4wdi_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4wdi\"},{\"model_identifier\":\"1qj0\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1999-06-18\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.4,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1qj0_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1qj0\"},{\"model_identifier\":\"4gbk\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-07-27\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.4,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4gbk_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4gbk\"},{\"model_identifier\":\"1qj0\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1999-06-18\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.4,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1qj0_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1qj0\"},{\"model_identifier\":\"4gbk\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-07-27\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.4,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4gbk_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4gbk\"},{\"model_identifier\":\"1jk8\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2001-07-11\",\"sequence_identity\":100.0,\"uniprot_start\":35,\"uniprot_end\":47,\"resolution\":2.4,\"coverage\":15.12,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1jk8_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1jk8\"},{\"model_identifier\":\"5uru\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-02-13\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.41,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5uru_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5uru\"},{\"model_identifier\":\"2wrw\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-02\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":49,\"resolution\":2.41,\"coverage\":29.07,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2wrw_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2wrw\"},{\"model_identifier\":\"2wrw\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-02\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.41,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2wrw_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2wrw\"},{\"model_identifier\":\"5uru\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-02-13\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.41,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5uru_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5uru\"},{\"model_identifier\":\"6z7w\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2020-06-02\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.42,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6z7w_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6z7w\"},{\"model_identifier\":\"6z7w\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2020-06-02\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.42,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6z7w_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6z7w\"},{\"model_identifier\":\"1jca\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2001-06-08\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.5,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1jca_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1jca\"},{\"model_identifier\":\"3jsd\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-10\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.5,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3jsd_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3jsd\"},{\"model_identifier\":\"1b9e\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1998-11-12\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.5,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1b9e_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1b9e\"},{\"model_identifier\":\"4gbl\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-07-27\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.5,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4gbl_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4gbl\"},{\"model_identifier\":\"1jca\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2001-06-08\",\"sequence_identity\":95.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.5,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1jca_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1jca\"},{\"model_identifier\":\"3jsd\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-10\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.5,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3jsd_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3jsd\"},{\"model_identifier\":\"1b9e\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1998-11-12\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.5,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1b9e_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1b9e\"},{\"model_identifier\":\"4gbl\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-07-27\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.5,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4gbl_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4gbl\"},{\"model_identifier\":\"4y19\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-02-07\",\"sequence_identity\":100.0,\"uniprot_start\":75,\"uniprot_end\":90,\"resolution\":2.5,\"coverage\":18.6,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4y19_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4y19\"},{\"model_identifier\":\"4gbi\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-07-27\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.502,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4gbi_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4gbi\"},{\"model_identifier\":\"4gbi\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-07-27\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.502,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4gbi_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4gbi\"},{\"model_identifier\":\"2ws7\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-03\",\"sequence_identity\":96.0,\"uniprot_start\":25,\"uniprot_end\":50,\"resolution\":2.59,\"coverage\":30.23,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2ws7_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2ws7\"},{\"model_identifier\":\"2ws7\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-09-03\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.59,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2ws7_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2ws7\"},{\"model_identifier\":\"2wby\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-03-06\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":109,\"resolution\":2.6,\"coverage\":23.26,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2wby_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2wby\"},{\"model_identifier\":\"2wby\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-03-06\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":43,\"resolution\":2.6,\"coverage\":22.09,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2wby_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2wby\"},{\"model_identifier\":\"3utt\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2011-11-26\",\"sequence_identity\":100.0,\"uniprot_start\":15,\"uniprot_end\":24,\"resolution\":2.6,\"coverage\":0.0,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3utt_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3utt\"},{\"model_identifier\":\"3uts\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2011-11-26\",\"sequence_identity\":100.0,\"uniprot_start\":15,\"uniprot_end\":24,\"resolution\":2.712,\"coverage\":0.0,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3uts_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3uts\"},{\"model_identifier\":\"4unh\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-05-28\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.75,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4unh_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4unh\"},{\"model_identifier\":\"4unh\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-05-28\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.75,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4unh_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4unh\"},{\"model_identifier\":\"2wc0\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-03-06\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.8,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2wc0_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2wc0\"},{\"model_identifier\":\"2wc0\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-03-06\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.8,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2wc0_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2wc0\"},{\"model_identifier\":\"5wdm\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-07-05\",\"sequence_identity\":57.0,\"uniprot_start\":25,\"uniprot_end\":110,\"resolution\":2.803,\"coverage\":66.28,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5wdm_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5wdm\"},{\"model_identifier\":\"6vep\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2020-01-02\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":2.9,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6vep_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6vep\"},{\"model_identifier\":\"6vep\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2020-01-02\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":2.9,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6vep_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6vep\"},{\"model_identifier\":\"5hyj\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2016-02-01\",\"sequence_identity\":90.0,\"uniprot_start\":15,\"uniprot_end\":24,\"resolution\":3.06,\"coverage\":0.0,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5hyj_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5hyj\"},{\"model_identifier\":\"6hn5\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2018-09-14\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":3.2,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6hn5_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6hn5\"},{\"model_identifier\":\"6hn5\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2018-09-14\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":3.2,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6hn5_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6hn5\"},{\"model_identifier\":\"5cjo\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-07-14\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":109,\"resolution\":3.287,\"coverage\":23.26,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5cjo_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5cjo\"},{\"model_identifier\":\"4oga\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-01-15\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":3.5,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4oga_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4oga\"},{\"model_identifier\":\"4oga\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-01-15\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":3.5,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4oga_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4oga\"},{\"model_identifier\":\"6b70\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-10-03\",\"sequence_identity\":100.0,\"uniprot_start\":1,\"uniprot_end\":110,\"resolution\":3.7,\"coverage\":100.0,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6b70_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6b70\"},{\"model_identifier\":\"6b3q\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-09-22\",\"sequence_identity\":100.0,\"uniprot_start\":1,\"uniprot_end\":110,\"resolution\":3.7,\"coverage\":100.0,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6b3q_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6b3q\"},{\"model_identifier\":\"6bfc\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-10-26\",\"sequence_identity\":100.0,\"uniprot_start\":1,\"uniprot_end\":110,\"resolution\":3.7,\"coverage\":100.0,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6bfc_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6bfc\"},{\"model_identifier\":\"7bw8\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2020-04-14\",\"sequence_identity\":86.0,\"uniprot_start\":25,\"uniprot_end\":110,\"resolution\":3.8,\"coverage\":86.05,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/7bw8_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/7bw8\"},{\"model_identifier\":\"3w11\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-11-06\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":3.9,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3w11_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3w11\"},{\"model_identifier\":\"3w11\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-11-06\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":3.9,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3w11_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3w11\"},{\"model_identifier\":\"5wob\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-08-01\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":109,\"resolution\":3.95,\"coverage\":23.26,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5wob_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5wob\"},{\"model_identifier\":\"4y1a\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-02-07\",\"sequence_identity\":100.0,\"uniprot_start\":75,\"uniprot_end\":90,\"resolution\":4.0,\"coverage\":18.6,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4y1a_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4y1a\"},{\"model_identifier\":\"7bw7\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2020-04-13\",\"sequence_identity\":86.0,\"uniprot_start\":25,\"uniprot_end\":110,\"resolution\":4.1,\"coverage\":86.05,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/7bw7_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/7bw7\"},{\"model_identifier\":\"6sof\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-08-29\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":4.3,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6sof_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6sof\"},{\"model_identifier\":\"6ce9\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2018-02-11\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":4.3,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6ce9_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6ce9\"},{\"model_identifier\":\"6sof\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-08-29\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":4.3,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6sof_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6sof\"},{\"model_identifier\":\"3w12\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-11-06\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":49,\"resolution\":4.301,\"coverage\":29.07,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3w12_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3w12\"},{\"model_identifier\":\"3w12\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-11-06\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":4.301,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3w12_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3w12\"},{\"model_identifier\":\"3w13\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-11-06\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":49,\"resolution\":4.303,\"coverage\":29.07,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3w13_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3w13\"},{\"model_identifier\":\"3w13\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-11-06\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":4.303,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3w13_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3w13\"},{\"model_identifier\":\"6jk8\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-02-27\",\"sequence_identity\":100.0,\"uniprot_start\":1,\"uniprot_end\":110,\"resolution\":4.7,\"coverage\":100.0,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6jk8_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6jk8\"},{\"model_identifier\":\"6ceb\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2018-02-11\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":4.7,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6ceb_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6ceb\"},{\"model_identifier\":\"7bwa\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2020-04-14\",\"sequence_identity\":86.0,\"uniprot_start\":25,\"uniprot_end\":110,\"resolution\":4.9,\"coverage\":86.05,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/7bwa_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/7bwa\"},{\"model_identifier\":\"6ce7\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2018-02-11\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":7.4,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6ce7_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6ce7\"},{\"model_identifier\":\"6jr3\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-04-02\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":14.5,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6jr3_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6jr3\"},{\"model_identifier\":\"6jr3\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-04-02\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":14.5,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6jr3_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6jr3\"},{\"model_identifier\":\"2kqp\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-11-12\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":110,\"resolution\":null,\"coverage\":100.0,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2kqp_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2kqp\"},{\"model_identifier\":\"1efe\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2000-02-08\",\"sequence_identity\":65.0,\"uniprot_start\":25,\"uniprot_end\":110,\"resolution\":null,\"coverage\":69.77,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1efe_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1efe\"},{\"model_identifier\":\"6u46\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-08-23\",\"sequence_identity\":61.0,\"uniprot_start\":25,\"uniprot_end\":109,\"resolution\":null,\"coverage\":67.44,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6u46_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6u46\"},{\"model_identifier\":\"1sju\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1997-10-09\",\"sequence_identity\":56.0,\"uniprot_start\":25,\"uniprot_end\":110,\"resolution\":null,\"coverage\":58.14,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1sju_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1sju\"},{\"model_identifier\":\"5mwq\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-01-19\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":56,\"resolution\":null,\"coverage\":37.21,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5mwq_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5mwq\"},{\"model_identifier\":\"6k59\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-05-28\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":56,\"resolution\":null,\"coverage\":37.21,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6k59_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6k59\"},{\"model_identifier\":\"1t0c\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2004-04-08\",\"sequence_identity\":100.0,\"uniprot_start\":57,\"uniprot_end\":87,\"resolution\":null,\"coverage\":36.05,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1t0c_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1t0c\"},{\"model_identifier\":\"5mhd\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2016-11-24\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":55,\"resolution\":null,\"coverage\":36.05,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5mhd_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5mhd\"},{\"model_identifier\":\"2lgb\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2011-07-25\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":55,\"resolution\":null,\"coverage\":36.05,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2lgb_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2lgb\"},{\"model_identifier\":\"2mvd\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-10-02\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2mvd_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2mvd\"},{\"model_identifier\":\"2mvc\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-10-02\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2mvc_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2mvc\"},{\"model_identifier\":\"1k3m\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2001-10-03\",\"sequence_identity\":90.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1k3m_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1k3m\"},{\"model_identifier\":\"2juu\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-09-03\",\"sequence_identity\":90.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2juu_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2juu\"},{\"model_identifier\":\"1hiq\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1993-03-05\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1hiq_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1hiq\"},{\"model_identifier\":\"2juv\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-09-05\",\"sequence_identity\":90.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2juv_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2juv\"},{\"model_identifier\":\"2rn5\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-12-06\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2rn5_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2rn5\"},{\"model_identifier\":\"2kxk\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2010-05-07\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2kxk_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2kxk\"},{\"model_identifier\":\"2hiu\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1996-10-08\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2hiu_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2hiu\"},{\"model_identifier\":\"2l1y\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2010-08-09\",\"sequence_identity\":87.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2l1y_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2l1y\"},{\"model_identifier\":\"2l1z\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2010-08-09\",\"sequence_identity\":90.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2l1z_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2l1z\"},{\"model_identifier\":\"2kju\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-06-10\",\"sequence_identity\":90.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2kju_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2kju\"},{\"model_identifier\":\"1xgl\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1996-10-10\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1xgl_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1xgl\"},{\"model_identifier\":\"1jco\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2001-06-11\",\"sequence_identity\":93.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1jco_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1jco\"},{\"model_identifier\":\"2jv1\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-09-11\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2jv1_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2jv1\"},{\"model_identifier\":\"2kqq\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-11-13\",\"sequence_identity\":87.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2kqq_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2kqq\"},{\"model_identifier\":\"1fu2\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2000-09-13\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1fu2_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1fu2\"},{\"model_identifier\":\"1kmf\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2001-12-14\",\"sequence_identity\":90.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1kmf_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1kmf\"},{\"model_identifier\":\"1vkt\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1996-10-14\",\"sequence_identity\":90.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1vkt_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1vkt\"},{\"model_identifier\":\"1fub\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2000-09-14\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1fub_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1fub\"},{\"model_identifier\":\"2n2x\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-05-15\",\"sequence_identity\":90.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2n2x_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2n2x\"},{\"model_identifier\":\"2n2v\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-05-15\",\"sequence_identity\":93.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2n2v_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2n2v\"},{\"model_identifier\":\"2n2w\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-05-15\",\"sequence_identity\":93.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2n2w_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2n2w\"},{\"model_identifier\":\"1t1k\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2004-04-16\",\"sequence_identity\":87.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1t1k_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1t1k\"},{\"model_identifier\":\"1t1p\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2004-04-16\",\"sequence_identity\":87.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1t1p_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1t1p\"},{\"model_identifier\":\"1t1q\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2004-04-16\",\"sequence_identity\":87.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1t1q_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1t1q\"},{\"model_identifier\":\"2mpg\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-05-17\",\"sequence_identity\":90.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2mpg_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2mpg\"},{\"model_identifier\":\"1sf1\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2004-02-19\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1sf1_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1sf1\"},{\"model_identifier\":\"2mpi\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-05-19\",\"sequence_identity\":87.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2mpi_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2mpi\"},{\"model_identifier\":\"2jmn\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2006-11-21\",\"sequence_identity\":90.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2jmn_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2jmn\"},{\"model_identifier\":\"2k9r\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2008-10-23\",\"sequence_identity\":87.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2k9r_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2k9r\"},{\"model_identifier\":\"6x4x\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2020-05-24\",\"sequence_identity\":87.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6x4x_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6x4x\"},{\"model_identifier\":\"1lkq\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2002-04-25\",\"sequence_identity\":90.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1lkq_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1lkq\"},{\"model_identifier\":\"2m1d\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-11-26\",\"sequence_identity\":93.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2m1d_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2m1d\"},{\"model_identifier\":\"2m1e\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-11-26\",\"sequence_identity\":93.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2m1e_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2m1e\"},{\"model_identifier\":\"2mli\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-02-27\",\"sequence_identity\":90.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2mli_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2mli\"},{\"model_identifier\":\"2hh4\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2006-06-27\",\"sequence_identity\":87.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2hh4_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2hh4\"},{\"model_identifier\":\"2m2m\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-12-28\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2m2m_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2m2m\"},{\"model_identifier\":\"2aiy\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1998-12-28\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2aiy_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2aiy\"},{\"model_identifier\":\"1hit\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1992-02-28\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1hit_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1hit\"},{\"model_identifier\":\"2hho\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2006-06-28\",\"sequence_identity\":87.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2hho_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2hho\"},{\"model_identifier\":\"1hls\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1995-06-28\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1hls_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1hls\"},{\"model_identifier\":\"2m2n\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-12-29\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2m2n_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2m2n\"},{\"model_identifier\":\"2m2o\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-12-29\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2m2o_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2m2o\"},{\"model_identifier\":\"2m2p\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-12-29\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2m2p_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2m2p\"},{\"model_identifier\":\"3aiy\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1998-12-29\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3aiy_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3aiy\"},{\"model_identifier\":\"4aiy\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1998-12-29\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4aiy_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4aiy\"},{\"model_identifier\":\"5aiy\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1998-12-29\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5aiy_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5aiy\"},{\"model_identifier\":\"2kjj\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-05-29\",\"sequence_identity\":93.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2kjj_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2kjj\"},{\"model_identifier\":\"2k91\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2008-09-29\",\"sequence_identity\":87.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2k91_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2k91\"},{\"model_identifier\":\"1ai0\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1997-04-30\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1ai0_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1ai0\"},{\"model_identifier\":\"1aiy\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1997-04-30\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1aiy_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1aiy\"},{\"model_identifier\":\"2h67\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2006-05-30\",\"sequence_identity\":87.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2h67_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2h67\"},{\"model_identifier\":\"1mhi\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1994-11-30\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1mhi_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1mhi\"},{\"model_identifier\":\"2jum\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-08-31\",\"sequence_identity\":90.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":34.88,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2jum_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2jum\"},{\"model_identifier\":\"1sjt\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1997-10-09\",\"sequence_identity\":93.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":null,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1sjt_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1sjt\"},{\"model_identifier\":\"1a7f\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1998-03-12\",\"sequence_identity\":93.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":null,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1a7f_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1a7f\"},{\"model_identifier\":\"1iog\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1998-08-13\",\"sequence_identity\":86.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":null,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1iog_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1iog\"},{\"model_identifier\":\"1ioh\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1998-08-13\",\"sequence_identity\":86.0,\"uniprot_start\":25,\"uniprot_end\":53,\"resolution\":null,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1ioh_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1ioh\"},{\"model_identifier\":\"1mhj\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1994-11-30\",\"sequence_identity\":97.0,\"uniprot_start\":25,\"uniprot_end\":54,\"resolution\":null,\"coverage\":33.72,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1mhj_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1mhj\"},{\"model_identifier\":\"1hui\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1996-03-29\",\"sequence_identity\":89.0,\"uniprot_start\":26,\"uniprot_end\":53,\"resolution\":null,\"coverage\":32.56,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1hui_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1hui\"},{\"model_identifier\":\"1his\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1992-02-28\",\"sequence_identity\":100.0,\"uniprot_start\":25,\"uniprot_end\":49,\"resolution\":null,\"coverage\":29.07,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1his_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1his\"},{\"model_identifier\":\"2mvc\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-10-02\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2mvc_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2mvc\"},{\"model_identifier\":\"2mvd\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-10-02\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2mvd_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2mvd\"},{\"model_identifier\":\"1k3m\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2001-10-03\",\"sequence_identity\":95.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1k3m_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1k3m\"},{\"model_identifier\":\"2juu\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-09-03\",\"sequence_identity\":95.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2juu_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2juu\"},{\"model_identifier\":\"1hiq\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1993-03-05\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1hiq_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1hiq\"},{\"model_identifier\":\"2juv\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-09-05\",\"sequence_identity\":95.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2juv_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2juv\"},{\"model_identifier\":\"2rn5\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-12-06\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2rn5_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2rn5\"},{\"model_identifier\":\"2kxk\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2010-05-07\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2kxk_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2kxk\"},{\"model_identifier\":\"2hiu\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1996-10-08\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2hiu_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2hiu\"},{\"model_identifier\":\"2l1z\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2010-08-09\",\"sequence_identity\":86.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2l1z_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2l1z\"},{\"model_identifier\":\"2l1y\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2010-08-09\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2l1y_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2l1y\"},{\"model_identifier\":\"1sjt\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1997-10-09\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1sjt_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1sjt\"},{\"model_identifier\":\"2kju\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-06-10\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2kju_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2kju\"},{\"model_identifier\":\"1xgl\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1996-10-10\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1xgl_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1xgl\"},{\"model_identifier\":\"1jco\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2001-06-11\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1jco_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1jco\"},{\"model_identifier\":\"2jv1\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-09-11\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2jv1_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2jv1\"},{\"model_identifier\":\"1a7f\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1998-03-12\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1a7f_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1a7f\"},{\"model_identifier\":\"1iog\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1998-08-13\",\"sequence_identity\":95.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1iog_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1iog\"},{\"model_identifier\":\"1ioh\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1998-08-13\",\"sequence_identity\":95.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1ioh_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1ioh\"},{\"model_identifier\":\"2kqq\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-11-13\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2kqq_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2kqq\"},{\"model_identifier\":\"1fu2\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2000-09-13\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1fu2_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1fu2\"},{\"model_identifier\":\"1kmf\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2001-12-14\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1kmf_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1kmf\"},{\"model_identifier\":\"1vkt\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1996-10-14\",\"sequence_identity\":90.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1vkt_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1vkt\"},{\"model_identifier\":\"1fub\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2000-09-14\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1fub_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1fub\"},{\"model_identifier\":\"2n2v\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-05-15\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2n2v_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2n2v\"},{\"model_identifier\":\"2n2w\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-05-15\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2n2w_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2n2w\"},{\"model_identifier\":\"2n2x\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2015-05-15\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2n2x_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2n2x\"},{\"model_identifier\":\"1t1k\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2004-04-16\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1t1k_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1t1k\"},{\"model_identifier\":\"1t1p\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2004-04-16\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1t1p_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1t1p\"},{\"model_identifier\":\"1t1q\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2004-04-16\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1t1q_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1t1q\"},{\"model_identifier\":\"2mpg\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-05-17\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2mpg_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2mpg\"},{\"model_identifier\":\"1sf1\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2004-02-19\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1sf1_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1sf1\"},{\"model_identifier\":\"5mwq\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2017-01-19\",\"sequence_identity\":95.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5mwq_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5mwq\"},{\"model_identifier\":\"2mpi\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-05-19\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2mpi_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2mpi\"},{\"model_identifier\":\"2jmn\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2006-11-21\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2jmn_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2jmn\"},{\"model_identifier\":\"2k9r\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2008-10-23\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2k9r_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2k9r\"},{\"model_identifier\":\"6x4x\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2020-05-24\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6x4x_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6x4x\"},{\"model_identifier\":\"5mhd\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2016-11-24\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5mhd_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5mhd\"},{\"model_identifier\":\"1lkq\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2002-04-25\",\"sequence_identity\":90.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1lkq_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1lkq\"},{\"model_identifier\":\"2lgb\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2011-07-25\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2lgb_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2lgb\"},{\"model_identifier\":\"2m1d\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-11-26\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2m1d_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2m1d\"},{\"model_identifier\":\"2m1e\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-11-26\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2m1e_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2m1e\"},{\"model_identifier\":\"2mli\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2014-02-27\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2mli_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2mli\"},{\"model_identifier\":\"2hh4\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2006-06-27\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2hh4_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2hh4\"},{\"model_identifier\":\"2m2m\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-12-28\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2m2m_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2m2m\"},{\"model_identifier\":\"2aiy\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1998-12-28\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2aiy_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2aiy\"},{\"model_identifier\":\"1his\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1992-02-28\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1his_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1his\"},{\"model_identifier\":\"1hit\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1992-02-28\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1hit_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1hit\"},{\"model_identifier\":\"2hho\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2006-06-28\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2hho_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2hho\"},{\"model_identifier\":\"1hls\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1995-06-28\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1hls_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1hls\"},{\"model_identifier\":\"2m2n\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-12-29\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2m2n_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2m2n\"},{\"model_identifier\":\"2m2o\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-12-29\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2m2o_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2m2o\"},{\"model_identifier\":\"2m2p\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2012-12-29\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2m2p_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2m2p\"},{\"model_identifier\":\"3aiy\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1998-12-29\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/3aiy_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/3aiy\"},{\"model_identifier\":\"4aiy\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1998-12-29\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/4aiy_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/4aiy\"},{\"model_identifier\":\"5aiy\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1998-12-29\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/5aiy_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/5aiy\"},{\"model_identifier\":\"1hui\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1996-03-29\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1hui_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1hui\"},{\"model_identifier\":\"2kjj\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2009-05-29\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2kjj_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2kjj\"},{\"model_identifier\":\"2k91\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2008-09-29\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2k91_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2k91\"},{\"model_identifier\":\"1ai0\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1997-04-30\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1ai0_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1ai0\"},{\"model_identifier\":\"1aiy\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1997-04-30\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1aiy_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1aiy\"},{\"model_identifier\":\"2h67\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2006-05-30\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2h67_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2h67\"},{\"model_identifier\":\"1mhi\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1994-11-30\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1mhi_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1mhi\"},{\"model_identifier\":\"1mhj\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"1994-11-30\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/1mhj_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/1mhj\"},{\"model_identifier\":\"2jum\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2007-08-31\",\"sequence_identity\":95.0,\"uniprot_start\":90,\"uniprot_end\":110,\"resolution\":null,\"coverage\":24.42,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/2jum_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/2jum\"},{\"model_identifier\":\"6k59\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"PDBe\",\"created\":\"2019-05-28\",\"sequence_identity\":100.0,\"uniprot_start\":90,\"uniprot_end\":109,\"resolution\":null,\"coverage\":23.26,\"model_url\":\"https://www.ebi.ac.uk/pdbe/static/entry/6k59_updated.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://www.ebi.ac.uk/pdbe/entry/pdb/6k59\"},{\"model_identifier\":\"PED00095e000\",\"model_category\":\"CONFORMATIONAL ENSEMBLE\",\"provider\":\"PED\",\"created\":\"2020-10-01\",\"uniprot_start\":25,\"uniprot_end\":54,\"model_url\":\"https://proteinensemble.org/api/ensemble/PED00095e000\",\"model_format\":\"PDB\",\"model_page_url\":\"https://proteinensemble.org/PED00095\",\"number_of_conformers\":25,\"ensemble_sample_url\":\"https://proteinensemble.org/api/ensemble_sample/PED00095e000\",\"ensemble_sample_format\":\"MMCIF\"},{\"model_identifier\":\"PED00104e000\",\"model_category\":\"CONFORMATIONAL ENSEMBLE\",\"provider\":\"PED\",\"created\":\"2020-10-01\",\"uniprot_start\":90,\"uniprot_end\":110,\"model_url\":\"https://proteinensemble.org/api/ensemble/PED00104e000\",\"model_format\":\"PDB\",\"model_page_url\":\"https://proteinensemble.org/PED00104\",\"number_of_conformers\":50,\"ensemble_sample_url\":\"https://proteinensemble.org/api/ensemble_sample/PED00104e000\",\"ensemble_sample_format\":\"MMCIF\"},{\"model_identifier\":\"PED00094e000\",\"model_category\":\"CONFORMATIONAL ENSEMBLE\",\"provider\":\"PED\",\"created\":\"2020-10-01\",\"uniprot_start\":25,\"uniprot_end\":54,\"model_url\":\"https://proteinensemble.org/api/ensemble/PED00094e000\",\"model_format\":\"PDB\",\"model_page_url\":\"https://proteinensemble.org/PED00094\",\"number_of_conformers\":25,\"ensemble_sample_url\":\"https://proteinensemble.org/api/ensemble_sample/PED00094e000\",\"ensemble_sample_format\":\"MMCIF\"},{\"model_identifier\":\"PED00104e000\",\"model_category\":\"CONFORMATIONAL ENSEMBLE\",\"provider\":\"PED\",\"created\":\"2020-10-01\",\"uniprot_start\":25,\"uniprot_end\":54,\"model_url\":\"https://proteinensemble.org/api/ensemble/PED00104e000\",\"model_format\":\"PDB\",\"model_page_url\":\"https://proteinensemble.org/PED00104\",\"number_of_conformers\":50,\"ensemble_sample_url\":\"https://proteinensemble.org/api/ensemble_sample/PED00104e000\",\"ensemble_sample_format\":\"MMCIF\"},{\"model_identifier\":\"PED00103e000\",\"model_category\":\"CONFORMATIONAL ENSEMBLE\",\"provider\":\"PED\",\"created\":\"2020-10-01\",\"uniprot_start\":90,\"uniprot_end\":110,\"model_url\":\"https://proteinensemble.org/api/ensemble/PED00103e000\",\"model_format\":\"PDB\",\"model_page_url\":\"https://proteinensemble.org/PED00103\",\"number_of_conformers\":30,\"ensemble_sample_url\":\"https://proteinensemble.org/api/ensemble_sample/PED00103e000\",\"ensemble_sample_format\":\"MMCIF\"},{\"model_identifier\":\"PED00102e000\",\"model_category\":\"CONFORMATIONAL ENSEMBLE\",\"provider\":\"PED\",\"created\":\"2020-10-01\",\"uniprot_start\":90,\"uniprot_end\":110,\"model_url\":\"https://proteinensemble.org/api/ensemble/PED00102e000\",\"model_format\":\"PDB\",\"model_page_url\":\"https://proteinensemble.org/PED00102\",\"number_of_conformers\":40,\"ensemble_sample_url\":\"https://proteinensemble.org/api/ensemble_sample/PED00102e000\",\"ensemble_sample_format\":\"MMCIF\"},{\"model_identifier\":\"PED00093e000\",\"model_category\":\"CONFORMATIONAL ENSEMBLE\",\"provider\":\"PED\",\"created\":\"2020-10-01\",\"uniprot_start\":90,\"uniprot_end\":110,\"model_url\":\"https://proteinensemble.org/api/ensemble/PED00093e000\",\"model_format\":\"PDB\",\"model_page_url\":\"https://proteinensemble.org/PED00093\",\"number_of_conformers\":25,\"ensemble_sample_url\":\"https://proteinensemble.org/api/ensemble_sample/PED00093e000\",\"ensemble_sample_format\":\"MMCIF\"},{\"model_identifier\":\"PED00093e000\",\"model_category\":\"CONFORMATIONAL ENSEMBLE\",\"provider\":\"PED\",\"created\":\"2020-10-01\",\"uniprot_start\":25,\"uniprot_end\":54,\"model_url\":\"https://proteinensemble.org/api/ensemble/PED00093e000\",\"model_format\":\"PDB\",\"model_page_url\":\"https://proteinensemble.org/PED00093\",\"number_of_conformers\":25,\"ensemble_sample_url\":\"https://proteinensemble.org/api/ensemble_sample/PED00093e000\",\"ensemble_sample_format\":\"MMCIF\"},{\"model_identifier\":\"PED00094e000\",\"model_category\":\"CONFORMATIONAL ENSEMBLE\",\"provider\":\"PED\",\"created\":\"2020-10-01\",\"uniprot_start\":90,\"uniprot_end\":110,\"model_url\":\"https://proteinensemble.org/api/ensemble/PED00094e000\",\"model_format\":\"PDB\",\"model_page_url\":\"https://proteinensemble.org/PED00094\",\"number_of_conformers\":25,\"ensemble_sample_url\":\"https://proteinensemble.org/api/ensemble_sample/PED00094e000\",\"ensemble_sample_format\":\"MMCIF\"},{\"model_identifier\":\"PED00096e000\",\"model_category\":\"CONFORMATIONAL ENSEMBLE\",\"provider\":\"PED\",\"created\":\"2020-10-01\",\"uniprot_start\":25,\"uniprot_end\":54,\"model_url\":\"https://proteinensemble.org/api/ensemble/PED00096e000\",\"model_format\":\"PDB\",\"model_page_url\":\"https://proteinensemble.org/PED00096\",\"number_of_conformers\":35,\"ensemble_sample_url\":\"https://proteinensemble.org/api/ensemble_sample/PED00096e000\",\"ensemble_sample_format\":\"MMCIF\"},{\"model_identifier\":\"PED00101e000\",\"model_category\":\"CONFORMATIONAL ENSEMBLE\",\"provider\":\"PED\",\"created\":\"2020-10-01\",\"uniprot_start\":90,\"uniprot_end\":110,\"model_url\":\"https://proteinensemble.org/api/ensemble/PED00101e000\",\"model_format\":\"PDB\",\"model_page_url\":\"https://proteinensemble.org/PED00101\",\"number_of_conformers\":25,\"ensemble_sample_url\":\"https://proteinensemble.org/api/ensemble_sample/PED00101e000\",\"ensemble_sample_format\":\"MMCIF\"},{\"model_identifier\":\"PED00096e000\",\"model_category\":\"CONFORMATIONAL ENSEMBLE\",\"provider\":\"PED\",\"created\":\"2020-10-01\",\"uniprot_start\":90,\"uniprot_end\":110,\"model_url\":\"https://proteinensemble.org/api/ensemble/PED00096e000\",\"model_format\":\"PDB\",\"model_page_url\":\"https://proteinensemble.org/PED00096\",\"number_of_conformers\":35,\"ensemble_sample_url\":\"https://proteinensemble.org/api/ensemble_sample/PED00096e000\",\"ensemble_sample_format\":\"MMCIF\"},{\"model_identifier\":\"PED00095e000\",\"model_category\":\"CONFORMATIONAL ENSEMBLE\",\"provider\":\"PED\",\"created\":\"2020-10-01\",\"uniprot_start\":90,\"uniprot_end\":110,\"model_url\":\"https://proteinensemble.org/api/ensemble/PED00095e000\",\"model_format\":\"PDB\",\"model_page_url\":\"https://proteinensemble.org/PED00095\",\"number_of_conformers\":25,\"ensemble_sample_url\":\"https://proteinensemble.org/api/ensemble_sample/PED00095e000\",\"ensemble_sample_format\":\"MMCIF\"},{\"model_identifier\":\"PED00101e000\",\"model_category\":\"CONFORMATIONAL ENSEMBLE\",\"provider\":\"PED\",\"created\":\"2020-10-01\",\"uniprot_start\":26,\"uniprot_end\":53,\"model_url\":\"https://proteinensemble.org/api/ensemble/PED00101e000\",\"model_format\":\"PDB\",\"model_page_url\":\"https://proteinensemble.org/PED00101\",\"number_of_conformers\":25,\"ensemble_sample_url\":\"https://proteinensemble.org/api/ensemble_sample/PED00101e000\",\"ensemble_sample_format\":\"MMCIF\"},{\"model_identifier\":\"PED00103e000\",\"model_category\":\"CONFORMATIONAL ENSEMBLE\",\"provider\":\"PED\",\"created\":\"2020-10-01\",\"uniprot_start\":25,\"uniprot_end\":54,\"model_url\":\"https://proteinensemble.org/api/ensemble/PED00103e000\",\"model_format\":\"PDB\",\"model_page_url\":\"https://proteinensemble.org/PED00103\",\"number_of_conformers\":30,\"ensemble_sample_url\":\"https://proteinensemble.org/api/ensemble_sample/PED00103e000\",\"ensemble_sample_format\":\"MMCIF\"},{\"model_identifier\":\"PED00102e000\",\"model_category\":\"CONFORMATIONAL ENSEMBLE\",\"provider\":\"PED\",\"created\":\"2020-10-01\",\"uniprot_start\":25,\"uniprot_end\":54,\"model_url\":\"https://proteinensemble.org/api/ensemble/PED00102e000\",\"model_format\":\"PDB\",\"model_page_url\":\"https://proteinensemble.org/PED00102\",\"number_of_conformers\":40,\"ensemble_sample_url\":\"https://proteinensemble.org/api/ensemble_sample/PED00102e000\",\"ensemble_sample_format\":\"MMCIF\"},{\"model_identifier\":\"61401d20ccef3f8332871ea3\",\"model_category\":\"TEMPLATE-BASED\",\"provider\":\"SWISS-MODEL\",\"created\":\"2021-09-14\",\"sequence_identity\":1.0,\"uniprot_start\":25,\"uniprot_end\":110,\"coverage\":0.782,\"confidence_version\":\"4.2.0\",\"confidence_avg_local_score\":0.526,\"model_url\":\"https://swissmodel.expasy.org/3d-beacons/uniprot/P01308.pdb?range=25-110&template=2lwz.1.A&provider=swissmodel\",\"model_format\":\"PDB\",\"confidence_type\":\"QMEANDisCo\"},{\"model_identifier\":\"AF-P01308-F1\",\"model_category\":\"DEEP-LEARNING\",\"provider\":\"AlphaFold DB\",\"created\":\"2021-07-01\",\"sequence_identity\":1.0,\"uniprot_start\":1,\"uniprot_end\":110,\"coverage\":100.0,\"model_url\":\"https://alphafold.ebi.ac.uk/files/AF-P01308-F1-model_v1.cif\",\"model_format\":\"MMCIF\",\"model_page_url\":\"https://alphafold.ebi.ac.uk/entry/P01308\"},{\"model_identifier\":\"2400\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"SASBDB\",\"created\":\"2018-11-11\",\"uniprot_start\":25,\"uniprot_end\":110,\"model_url\":\"https://www.sasbdb.org/media/pdb_file/SASDE25_fit1_model1.pdb\",\"model_format\":\"PDB\",\"model_page_url\":\"https://www.sasbdb.org/data/SASDE25\"},{\"model_identifier\":\"2396\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"SASBDB\",\"created\":\"2018-11-11\",\"uniprot_start\":25,\"uniprot_end\":110,\"model_url\":\"https://www.sasbdb.org/media/pdb_file/SASDE25_fit2_model1.pdb\",\"model_format\":\"PDB\",\"model_page_url\":\"https://www.sasbdb.org/data/SASDE25\"},{\"model_identifier\":\"2452\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"SASBDB\",\"created\":\"2019-04-07\",\"uniprot_start\":25,\"uniprot_end\":110,\"model_url\":\"https://www.sasbdb.org/media/pdb_file/SASDEV5_fit2_model1.pdb\",\"model_format\":\"PDB\",\"model_page_url\":\"https://www.sasbdb.org/data/SASDEV5\"},{\"model_identifier\":\"2453\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"SASBDB\",\"created\":\"2019-04-07\",\"uniprot_start\":25,\"uniprot_end\":110,\"model_url\":\"https://www.sasbdb.org/media/pdb_file/SASDEV5_fit3_model1.pdb\",\"model_format\":\"PDB\",\"model_page_url\":\"https://www.sasbdb.org/data/SASDEV5\"},{\"model_identifier\":\"2456\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"SASBDB\",\"created\":\"2019-04-07\",\"uniprot_start\":25,\"uniprot_end\":110,\"model_url\":\"https://www.sasbdb.org/media/pdb_file/SASDEW5_fit2_model1.pdb\",\"model_format\":\"PDB\",\"model_page_url\":\"https://www.sasbdb.org/data/SASDEW5\"},{\"model_identifier\":\"2457\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"SASBDB\",\"created\":\"2019-04-07\",\"uniprot_start\":25,\"uniprot_end\":110,\"model_url\":\"https://www.sasbdb.org/media/pdb_file/SASDEW5_fit3_model1.pdb\",\"model_format\":\"PDB\",\"model_page_url\":\"https://www.sasbdb.org/data/SASDEW5\"},{\"model_identifier\":\"2459\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"SASBDB\",\"created\":\"2019-04-07\",\"uniprot_start\":25,\"uniprot_end\":110,\"model_url\":\"https://www.sasbdb.org/media/pdb_file/SASDEX5_fit2_model1.pdb\",\"model_format\":\"PDB\",\"model_page_url\":\"https://www.sasbdb.org/data/SASDEX5\"},{\"model_identifier\":\"2460\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"SASBDB\",\"created\":\"2019-04-07\",\"uniprot_start\":25,\"uniprot_end\":110,\"model_url\":\"https://www.sasbdb.org/media/pdb_file/SASDEX5_fit3_model1.pdb\",\"model_format\":\"PDB\",\"model_page_url\":\"https://www.sasbdb.org/data/SASDEX5\"},{\"model_identifier\":\"2462\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"SASBDB\",\"created\":\"2019-04-07\",\"uniprot_start\":25,\"uniprot_end\":609,\"model_url\":\"https://www.sasbdb.org/media/pdb_file/SASDEY5_fit2_model1.pdb\",\"model_format\":\"PDB\",\"model_page_url\":\"https://www.sasbdb.org/data/SASDEY5\"},{\"model_identifier\":\"2463\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"SASBDB\",\"created\":\"2019-04-07\",\"uniprot_start\":25,\"uniprot_end\":609,\"model_url\":\"https://www.sasbdb.org/media/pdb_file/SASDEY5_fit3_model1.pdb\",\"model_format\":\"PDB\",\"model_page_url\":\"https://www.sasbdb.org/data/SASDEY5\"},{\"model_identifier\":\"2465\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"SASBDB\",\"created\":\"2019-04-07\",\"uniprot_start\":25,\"uniprot_end\":609,\"model_url\":\"https://www.sasbdb.org/media/pdb_file/SASDEZ5_fit2_model1.pdb\",\"model_format\":\"PDB\",\"model_page_url\":\"https://www.sasbdb.org/data/SASDEZ5\"},{\"model_identifier\":\"2467\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"SASBDB\",\"created\":\"2019-04-07\",\"uniprot_start\":25,\"uniprot_end\":609,\"model_url\":\"https://www.sasbdb.org/media/pdb_file/SASDEZ5_fit3_model1.pdb\",\"model_format\":\"PDB\",\"model_page_url\":\"https://www.sasbdb.org/data/SASDEZ5\"},{\"model_identifier\":\"2469\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"SASBDB\",\"created\":\"2019-04-07\",\"uniprot_start\":25,\"uniprot_end\":609,\"model_url\":\"https://www.sasbdb.org/media/pdb_file/SASDE26_fit2_model1.pdb\",\"model_format\":\"PDB\",\"model_page_url\":\"https://www.sasbdb.org/data/SASDE26\"},{\"model_identifier\":\"2470\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"SASBDB\",\"created\":\"2019-04-07\",\"uniprot_start\":25,\"uniprot_end\":609,\"model_url\":\"https://www.sasbdb.org/media/pdb_file/SASDE26_fit3_model1.pdb\",\"model_format\":\"PDB\",\"model_page_url\":\"https://www.sasbdb.org/data/SASDE26\"},{\"model_identifier\":\"4420\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"SASBDB\",\"created\":\"2020-12-18\",\"uniprot_start\":25,\"uniprot_end\":110,\"model_url\":\"https://www.sasbdb.org/media/pdb_file/SASDJY3_fit1_model1.pdb\",\"model_format\":\"PDB\",\"model_page_url\":\"https://www.sasbdb.org/data/SASDJY3\"},{\"model_identifier\":\"4421\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"SASBDB\",\"created\":\"2020-12-18\",\"uniprot_start\":25,\"uniprot_end\":110,\"model_url\":\"https://www.sasbdb.org/media/pdb_file/SASDJY3_fit1_model2.pdb\",\"model_format\":\"PDB\",\"model_page_url\":\"https://www.sasbdb.org/data/SASDJY3\"},{\"model_identifier\":\"4422\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"SASBDB\",\"created\":\"2020-12-18\",\"uniprot_start\":25,\"uniprot_end\":110,\"model_url\":\"https://www.sasbdb.org/media/pdb_file/SASDJZ3_fit1_model1.pdb\",\"model_format\":\"PDB\",\"model_page_url\":\"https://www.sasbdb.org/data/SASDJZ3\"},{\"model_identifier\":\"4423\",\"model_category\":\"EXPERIMENTALLY DETERMINED\",\"provider\":\"SASBDB\",\"created\":\"2020-12-18\",\"uniprot_start\":25,\"uniprot_end\":110,\"model_url\":\"https://www.sasbdb.org/media/pdb_file/SASDJZ3_fit1_model2.pdb\",\"model_format\":\"PDB\",\"model_page_url\":\"https://www.sasbdb.org/data/SASDJZ3\"}]}" } };

  public static void setMock()
  {
    FTSRestClient.createMockFTSRestClient(
            (FTSRestClient) TDBeaconsFTSRestClient.getInstance(),
            mocks);
  }

  private static String dev_url = "https://wwwdev.ebi.ac.uk/pdbe/pdbe-kb/3dbeacons/api/uniprot/summary/";

  /**
   * check that the mock request and response are the same as the response from
   * a live 3D-beacons endpoint
   * 
   * @throws Exception
   */
  @Test(groups = { "Network", "Integration" })
  public void verifyMockTDBRequest() throws Exception
  {
    for (String[] otherMock:mocks)
    {
    verifyMockTDBRequest(otherMock[0],otherMock[1]);
    }
  }
  private void verifyMockTDBRequest(String mockRequest, String _mockResponse) throws Exception
  {
    URL tdb_req = new URL(dev_url + mockRequest);
    byte[] resp = tdb_req.openStream().readAllBytes();
    String tresp = new String(resp, StandardCharsets.UTF_8);
    assertEquals(_mockResponse.trim(), tresp.trim());
  }

  @Test(groups = { "Functional" })
  public void testMockTDBRequest()
  {

    setMock();
    List<FTSDataColumnI> wantedFields = new ArrayList<FTSDataColumnI>();
    try
    {
      wantedFields.add(TDBeaconsFTSRestClient.getInstance()
              .getDataColumnByNameOrCode("Model Id"));
      wantedFields.add(TDBeaconsFTSRestClient.getInstance()
              .getDataColumnByNameOrCode("model_url"));
      wantedFields.add(TDBeaconsFTSRestClient.getInstance()
              .getDataColumnByNameOrCode("provider"));
      wantedFields.add(TDBeaconsFTSRestClient.getInstance()
              .getDataColumnByNameOrCode("model_category"));
      wantedFields.add(TDBeaconsFTSRestClient.getInstance()
              .getDataColumnByNameOrCode("qmean_avg_local_score"));
      wantedFields.add(TDBeaconsFTSRestClient.getInstance()
              .getDataColumnByNameOrCode("uniprot_start"));
      wantedFields.add(TDBeaconsFTSRestClient.getInstance()
              .getDataColumnByNameOrCode("uniprot_end"));
    } catch (Exception e1)
    {
      e1.printStackTrace();
    }
    System.out.println("wantedFields >>" + wantedFields);

    FTSRestRequest request = new FTSRestRequest();
    FTSRestResponse response;

    request.setResponseSize(100);
    request.setFieldToSearchBy("");
    request.setWantedFields(wantedFields);
    // check 404 behaviour
    request.setSearchTerm("P00000.json");

    try
    {
      response = TDBeaconsFTSRestClient.getInstance()
              .executeRequest(request);

      assertNull(response);
    } catch (Exception e)
    {
      e.printStackTrace();
      Assert.fail("Unexpected failure during mock 3DBeacons 404 test");
    }

    // check 200 behaviour
    request.setSearchTerm("P38398.json");
    System.out.println("request : " + request.getFieldToSearchBy());
    // System.out.println(request.toString());

    try
    {
      response = TDBeaconsFTSRestClient.getInstance()
              .executeRequest(request);
    } catch (Exception e)
    {
      e.printStackTrace();
      Assert.fail("Couldn't execute webservice call!");
      return;
    }
    assertTrue(response.getSearchSummary() != null);
    assertTrue(response.getNumberOfItemsFound() > 3); // 4 atm
    System.out.println("Search summary : \n" + response.getSearchSummary());

    // System.out.println(response.getSearchSummary().size());
  }

  @Test(groups = { "External", "Network" })
  public void executeRequestTest()
  {
    List<FTSDataColumnI> wantedFields = new ArrayList<FTSDataColumnI>();
    try
    {
      wantedFields.add(TDBeaconsFTSRestClient.getInstance()
              .getDataColumnByNameOrCode("Model Id"));
      wantedFields.add(TDBeaconsFTSRestClient.getInstance()
              .getDataColumnByNameOrCode("model_url"));
      wantedFields.add(TDBeaconsFTSRestClient.getInstance()
              .getDataColumnByNameOrCode("provider"));
      wantedFields.add(TDBeaconsFTSRestClient.getInstance()
              .getDataColumnByNameOrCode("model_category"));
      wantedFields.add(TDBeaconsFTSRestClient.getInstance()
              .getDataColumnByNameOrCode("confidence_avg_local_score"));
      wantedFields.add(TDBeaconsFTSRestClient.getInstance()
              .getDataColumnByNameOrCode("uniprot_start"));
      wantedFields.add(TDBeaconsFTSRestClient.getInstance()
              .getDataColumnByNameOrCode("uniprot_end"));
    } catch (Exception e1)
    {
      e1.printStackTrace();
    }
    System.out.println("wantedFields >>" + wantedFields);

    FTSRestRequest request = new FTSRestRequest();
    request.setResponseSize(100);
    request.setFieldToSearchBy("");
    request.setSearchTerm("P01318.json");
    request.setWantedFields(wantedFields);
    System.out.println("request : " + request.getFieldToSearchBy());
    // System.out.println(request.toString());

    FTSRestResponse response;
    try
    {
      response = TDBeaconsFTSRestClient.getInstance()
              .executeRequest(request);
    } catch (Exception e)
    {
      e.printStackTrace();
      Assert.fail("Couldn't execute webservice call!");
      return;
    }
    assertTrue(response.getSearchSummary() != null);
    assertTrue(response.getNumberOfItemsFound() > 3); // 4 atm
    System.out.println("Search summary : \n" + response.getSearchSummary());
    // System.out.println(response.getSearchSummary().size());
  }
}
